@@ -31,8 +31,8 @@ static KgThemeProvider *provider()
 {
     KgThemeProvider *prov = new KgThemeProvider;
     prov->discoverThemes(
-        "appdata", QLatin1String("themes"), //theme file location
-        QLatin1String("robotkill")          //default theme file name
+        "appdata", QStringLiteral("themes"), //theme file location
+        QStringLiteral("robotkill")          //default theme file name
     );
     return prov;
 }
@@ -60,7 +60,7 @@ Killbots::Renderer::Renderer()
 
 QCursor Killbots::Renderer::cursorFromAction(int direction)
 {
-    QString element = QString("cursor%1").arg(direction);
+    QString element = QStringLiteral("cursor%1").arg(direction);
     QPixmap pixmap = spritePixmap(element, QSize(42, 42));
     return QCursor(pixmap);
 }
@@ -68,7 +68,7 @@ QCursor Killbots::Renderer::cursorFromAction(int direction)
 QColor Killbots::Renderer::textColor()
 {
     if (m_cachedTheme != theme()->identifier()) {
-        m_textColor = spritePixmap("textcolor", QSize(3, 3)).toImage().pixel(1, 1);
+        m_textColor = spritePixmap(QStringLiteral("textcolor"), QSize(3, 3)).toImage().pixel(1, 1);
         m_cachedTheme = theme()->identifier();
     }
     return m_textColor;
@@ -76,6 +76,6 @@ QColor Killbots::Renderer::textColor()
 
 qreal Killbots::Renderer::aspectRatio()
 {
-    const QRectF tileRect = boundsOnSprite("cell");
+    const QRectF tileRect = boundsOnSprite(QStringLiteral("cell"));
     return qBound<qreal>(0.3333, tileRect.width() / tileRect.height(), 3.0);
 }
